==> ginkgocadx_2.4.1.1.orig.tar.gz: ginkgocadx-2.4.1.1/src/cadxcore/main/gui/license/acceptlicensedialog.cpp <==
/*
 *  
 *  $Id: acceptlicensedialog.cpp 3526 2011-03-16 19:56:19Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#include "acceptlicensedialog.h"
#include <wx/config.h>
#include <main/entorno.h>
#include <api/globals.h>
#include <main/licencia.h>
#include <string>
#include <sstream>
#include <api/internacionalizacion.h>

GNC::GUI::AcceptLicenseDialog::AcceptLicenseDialog(wxWindow* pPadre):GNC::GUI::AcceptLicenseDialogBase(pPadre)
{
	std::stringstream is;
	is << _Std("Ginkgo CADx license agreement version  ") << GNC::Entorno::Instance()->GetGinkgoVersion() << std::endl;	
	is << std::endl;	
	is << GINKGO_MENSAJE_LICENCIA << std::endl;
	is << std::endl;
	is << GNC::Entorno::Instance()->GetGinkgoCopyRight() << " MetaEmotion Healthcare " ;
	is << "http://healthcare.metaemotion.com" << std::endl;
	is << "contacto@metaemotion.com";

	m_pTextoLicencia->SetValue(wxString::FromUTF8(is.str().c_str()));
	Layout();
	m_buttonAceptar->SetFocus();
}

GNC::GUI::AcceptLicenseDialog::~AcceptLicenseDialog()
{
}

void GNC::GUI::AcceptLicenseDialog::OnAceptarClick(wxCommandEvent &event)
{
	wxConfigBase * config = wxConfigBase::Get();
	//se actualiza el fichero de configuracion
	config->SetPath(wxT("/GinkgoCore/Estacion"));
	config->Write(wxT("CheckForUpdates"),m_pCheckForUpdates->GetValue());
	config->Flush();
	event.Skip(true);
}

==> ginkgocadx_2.12.0.4889.orig.tar.gz: ginkgocadx-2.12.0.4889/src/cadxcore/main/gui/license/acceptlicensedialog.cpp <==
/*
 *  
 *  $Id: acceptlicensedialog.cpp 4641 2012-02-01 13:04:38Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#include "acceptlicensedialog.h"
#include <main/controllers/configurationcontroller.h>
#include <main/controllers/controladorpermisos.h>
#include <main/entorno.h>
#include <api/globals.h>
#include <main/licencia.h>
#include <string>
#include <sstream>


GNC::GUI::AcceptLicenseDialog::AcceptLicenseDialog(wxWindow* pPadre):GNC::GUI::AcceptLicenseDialogBase(pPadre)
{
	std::stringstream is;
	is << _Std("Ginkgo CADx license agreement version  ") << GNC::Entorno::Instance()->GetGinkgoVersion() << std::endl;	
	is << std::endl;	
	is << GNC::Entorno::Instance()->GetLicenseMessage() << std::endl;
	is << std::endl;
	is << GNC::Entorno::Instance()->GetGinkgoCopyRight() << " MetaEmotion Healthcare " ;
	is << "http://healthcare.metaemotion.com" << std::endl;
	is << "contacto@metaemotion.com";

	m_pTextoLicencia->SetValue(wxString::FromUTF8(is.str().c_str()));
	Layout();
	m_buttonAceptar->SetFocus();
	GNC::GCS::Permisos::EstadoPermiso updates = GNC::GCS::ControladorPermisos::Instance()->Get("core.update","check_updates");
	m_pCheckForUpdates->Show(updates);
	m_pCheckForUpdates->SetValue(updates);
}

GNC::GUI::AcceptLicenseDialog::~AcceptLicenseDialog()
{
}

void GNC::GUI::AcceptLicenseDialog::OnAceptarClick(wxCommandEvent &event)
{
	GNC::GCS::ConfigurationController::Instance()->writeBoolGeneral("/GinkgoCore/Estacion", "CheckForUpdates", m_pCheckForUpdates->GetValue());
	GNC::GCS::ConfigurationController::Instance()->Flush();
	event.Skip(true);
}
